========================================
``psyclone.tests.dynamo0p3_haloex_test``
========================================

.. automodule:: psyclone.tests.dynamo0p3_haloex_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.dynamo0p3_haloex_test
